<?php
/**
 * Yii 2 Hangman
 *
 * @author Marc Oliveras Galvez <admin@oligalma.com> 
 * @link http://www.oligalma.com
 * @copyright 2021 Oligalma
 * @license GPL License
 */

namespace app\modules\hangman\controllers;

use Yii;
use yii\helpers\Html;
use yii\web\Controller;
use yii\filters\VerbFilter;

class SiteController extends Controller
{
    public function behaviors()
    {
	return [
	    'verbs' => [
		'class' => VerbFilter::className(),
		'actions' => [
		    'guess'  => ['post'],
		],
	    ],
	];
    }
    
    public function actionIndex()
    {
        $levels = array('0' => 'Easy game: you are allowed 10 misses.',
                        '1' => 'Medium game: you are allowed 5 misses.',
                        '2' => 'Hard game: you are allowed 3 misses.');
                        
        if(isset($_POST['level']))
        {
            $this->redirect(array('start', 'level' => $_POST['level'])); 
        }
        
        return $this->render('index', array('levels' => $levels));
    }
    
    public function actionStart()
    {
        $lines = file(dirname(__FILE__) . '/../lib/dictionary.txt');      
        $word = $lines[rand(0, count($lines) - 1)];
        $word = substr($word, 0, strlen($word) - 1);
        
        Yii::$app->session['word'] = trim($word);
        Yii::$app->session['foundLetters'] = '';
        Yii::$app->session['win'] = null;
        
        $level = 0;
        if(isset($_GET['level']))
            $level = $_GET['level'];
        Yii::$app->session['level'] = $level;
        
        switch($level)
        {
            case 0: // Easy
                Yii::$app->session['lives'] = 10;
                break;
            case 1: // Medium
                Yii::$app->session['lives'] = 5;
                break;
            case 2: // Hard
                Yii::$app->session['lives'] = 3;
                break;                
        }
        
        Yii::$app->session['image'] = 0;
        
        return $this->render('start', array('blankWord' => str_repeat(Html::tag('span','_',array('class' => 'guessed-letter')), strlen($word))));
    }
    
    public function actionGuess()
    {
        $response = array();
        
        if(Yii::$app->session['win'] == null)
        {
            $letter = strtolower($_POST['letter']);
     
            if(strpos(strtolower(Yii::$app->session['word']), $letter) === false)
            {
                Yii::$app->session['lives'] -= 1;
                switch(Yii::$app->session['level'])
                {
                    case 0:
                        Yii::$app->session['image'] += 1;
                        break;
                    case 1:
                        Yii::$app->session['image'] += 2;
                        break;
                    case 2:
                            if(Yii::$app->session['image'] == 0)
                                Yii::$app->session['image'] = 3;
                            elseif(Yii::$app->session['image'] == 3)
                                Yii::$app->session['image'] = 6;
                            else
                                Yii::$app->session['image'] = 10;
                        break;
                }
                $response['image'] = Yii::$app->controller->module->assetsUrl[1] . '/images/hangman/' . Yii::$app->session['image'] . '.jpg';
                
                if(Yii::$app->session['lives'] == 0)
                {
                    Yii::$app->session['win'] = false;
                    $response['word'] = 'The word was: ' . Html::tag('b',Yii::$app->session['word'], array());
                }           
            }   
            else
            {
                Yii::$app->session['foundLetters'] .= $letter;
              
                $i = 0;
                $wordLetters = str_split(Yii::$app->session['word']);
                $foundLetters = str_split(Yii::$app->session['foundLetters']);
                foreach($wordLetters as $letter)
                {
                    $found = false;
                    
                    foreach($foundLetters as $letter2)
                    {
                        if($letter == $letter2)
                        {
                            $found = true;
                            break;
                        }
                    }
                    
                    if($found)
                        $i++;
                }  
                if($i == strlen(Yii::$app->session['word']))
                    Yii::$app->session['win'] = true;     
            }
        }

        $wordLetters = str_split(Yii::$app->session['word']);
        $foundLetters = str_split(Yii::$app->session['foundLetters']);
        $guessedWord = '';
        
        foreach($wordLetters as $letter)
        {
            $found = false;
            
            foreach($foundLetters as $letter2)
            {
                if($letter == $letter2)
                {
                    $found = true;
                    break;
                }
            }
            
            if($found)
                $guessedWord .= $letter;
            else
                $guessedWord .= Html::tag('span','_',array('class' => 'guessed-letter'));
        }  
      
        $response['win'] = Yii::$app->session['win'];
        $response['lives'] = Yii::$app->session['lives'];
        $response['guessedWord'] = $guessedWord;
        
        echo json_encode($response);  
    }
}
